use crate::events::Event;
use crate::handles::handle_agora_call::handle_agora_call;
use crate::handles::online_users_update::{online_messages, send_online_users_resp};
use crate::typing::message_typed::ClientMessageData;
use tokio::sync::mpsc::UnboundedSender;

pub async fn handle_ws_msg(
    client_message_data: &ClientMessageData,
    from_id: String,
    event_sender: UnboundedSender<Event>,
    connection_time: u128,
) {
    let msg_type = client_message_data.msg_type.clone();
    match msg_type.as_str() {
        "GetCompanyUserList" => {
            println!("收到客户端获取在线用户列表 {}", &from_id);
            // 需要主动发送在线人员更新事件
            if let Ok(online_users_json) = send_online_users_resp().await {
                if let Ok(formatted_json) = online_messages(online_users_json, from_id.clone()) {
                    if let Err(e) = event_sender.send(Event::SendClientMessage(
                        (from_id.clone(), connection_time),
                        formatted_json,
                        false,
                    )) {
                        println!(
                            "客户端要求更新在线列表 {}发送在线用户列表失败 {:?}",
                            &from_id, e
                        );
                    } else {
                        println!("客户端要求更新在线列表 {}发送在线用户列表成功", &from_id);
                    }
                }
            }
        }
        // 通话类消息直接托管给对应句柄即可
        "Call" | "CancelCall" | "Refuse" | "EndMeeting" | "Hangup" | "Connect" | "Mute"
        | "MuteAll" | "KickOut" | "MuteSelf" => {
            handle_agora_call(
                &client_message_data,
                &from_id,
                &event_sender,
                &connection_time,
            )
            .await;
        }
        // 针对其余消息类型，直接根据fromID -> toID规则发送即可
        _ => {}
    }
}
